@@ -33,16 +33,16 @@ by the user.
 
 sub collect {
     my $class = shift;
-    my $bryar = shift;
-    croak "Must pass in a Bryar object" unless UNIVERSAL::isa($bryar, "Bryar");
+    my $config = shift;
+    croak "Must pass in a Bryar::Config object" unless UNIVERSAL::isa($config, "Bryar::Config");
     my %args = @_;
-    $bryar->{arguments} = \%args;
+    $config->{arguments} = \%args;
     delete $args{format}; # Not interesting
     if (! keys %args) { # Default operation
-        return $class->collect_current($bryar);
+        return $class->collect_current($config);
     }
     my @docs = sort {$b->epoch <=> $a->epoch }
-        $bryar->{config}->source->search($bryar, %args);
+        $config->source->search($config, %args);
     return @docs;
 }
 
@@ -53,17 +53,17 @@ sub collect {
 
 Return the latest set of documents.
 
+TODO: make this configurable as well, to return X number or all posts X units of time back.
 =cut
 
 sub collect_current {
     my $self = shift;
-    my $bryar = shift;
-    croak "Must pass in a Bryar object" unless UNIVERSAL::isa($bryar, "Bryar");
-    my @docs = sort {$b->epoch <=> $a->epoch }
-                $bryar->{config}->source->search(
-                    $bryar,
-                    limit => $bryar->{config}->recent());
-    return @docs;
+    my $config = shift;
+    croak "Must pass in a Bryar::Config object" unless UNIVERSAL::isa($config, "Bryar::Config");
+    return sort {$b->epoch <=> $a->epoch }
+                $config->source->search(
+                    $config,
+                    limit => $config->recent());
 }
 
 
@@ -77,11 +77,8 @@ terms as Perl itself.
 
 Copyright (C) 2003, Simon Cozens C<simon@kasei.com>
 
-
 =head1 SEE ALSO
 
-
-
-
+=cut
 
 1;
