@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 use Template;
-our $VERSION = '1.0';
+our $VERSION = '1.1';
 
 =head1 NAME
 
@@ -40,12 +40,17 @@ Returns a page from templates and documents provided by the Bryar object.
 sub _tt {
     my ($class, $bryar) = @_;
     my @path = $bryar->{config}->datadir;
-    unshift @path, $bryar->{config}->datadir."/".$bryar->{arguments}->{subblog} 
-        if exists $bryar->{arguments}->{subblog};
+    unshift @path, $bryar->{config}->datadir."/".$bryar->{config}->{arguments}->{subblog} 
+        if exists $bryar->{config}->{arguments}->{subblog};
         
     @path = map { $_, $_."/templates" } @path;
     return Template->new({
-        INCLUDE_PATH => \@path
+        INCLUDE_PATH => \@path,
+	ABSOLUTE     => 1,
+        EVAL_PERL    => 1,
+        RELATIVE     => 1,
+        PRE_CHOMP    => 1,
+        POST_CHOMP   => 1,
     });
 }
 
@@ -55,6 +60,10 @@ sub _tt_process {
     my $tt = $class->_tt($bryar);
     $tt->process($filename, {
         documents => \@documents,
+        recent    => [$bryar->config()->collector()->collect($bryar->config())],
+        archive   => [
+            $bryar->config()->source()->all_but_recent($bryar->config())
+        ],
         bryar     => $bryar,
     }, \$output);
     if (!$output) {
@@ -69,6 +78,8 @@ error as reported by Template Toolkit was:
 EOF
         );
     }
+    # $output =~ s/\s+/ /g;
+    # $output =~ s/>\s+</></g;
     return $output;
 }
 
@@ -89,11 +100,25 @@ sub register_format {
     $formats{$format} = [$filename, $content_type];
 }
 
+# display formats
 __PACKAGE__->register_format( html => "template.html", "text/html" );
-__PACKAGE__->register_format( atom => "template.atom", "application/atom+xml" );
+
+# TODO: put formats in a formats/ folder by default, but add a config option
+# for their location.
+
+# syndication formats (full posts)
+__PACKAGE__->register_format( atom => "template.atom", "application/atom+xml" ); # "application/atom+xml" );
 __PACKAGE__->register_format( xml  => "template.rss",  "application/rdf+xml");
 __PACKAGE__->register_format( rss  => "template.rss",  "application/rdf+xml");
 __PACKAGE__->register_format( rdf  => "template.rss",  "application/rdf+xml");
+__PACKAGE__->register_format( rss2 => "template.rss2", "application/rss+xml");
+
+# syndication formats (excerpted posts)
+__PACKAGE__->register_format( atomexcerpt => "template.atomexcerpt", "application/atom+xml" );
+__PACKAGE__->register_format( xmlexcerpt  => "template.rssexcerpt", "application/rdf+xml");
+__PACKAGE__->register_format( rssexcerpt  => "template.rssexcerpt", "application/rdf+xml");
+__PACKAGE__->register_format( rdfexcerpt  => "template.rssexcerpt", "application/rdf+xml");
+__PACKAGE__->register_format( rss2excerpt => "template.rss2excerpt", "application/rss+xml");
 
 sub generate {
     my $class = shift;
@@ -106,24 +131,20 @@ sub generate {
     return ($ct, $class->_tt_process($file, @_));
 }
 
-
-
-
 =head1 LICENSE
 
 This module is free software, and may be distributed under the same
 terms as Perl itself.
 
-
 =head1 AUTHOR
 
 Copyright (C) 2003, Simon Cozens C<simon@kasei.com>
 
+some parts Copyright 2007 David Cantrell C<david@cantrell.org.uk>
+
 
 =head1 SEE ALSO
 
-
-
-
+=cut
 
 1;
